@@ -43,6 +43,7 @@
 #define DEVICEFILENAME "/uditab"
 #define TMPPOSTFIX ".tmp"
 #define MASKOPTSTR "umask="
+#define UIDOPTSTR "uid="
 
 typedef struct halevt_mount_udi
 {
@@ -668,6 +669,22 @@ void usage()
 ); 
 }
 
+int halevt_mount_add_option(char **options_array, char * option, int option_nr)
+{
+  option_nr++;
+  if ((realloc (options_array, option_nr * sizeof(char *))) == NULL)
+  {
+    fprintf (stderr, _("Out of memory\n"));
+    return 0;
+  }
+  if ((options_array[option_nr - 1] = strdup(option)) == NULL)
+  {
+    fprintf (stderr, _("Out of memory\n"));
+    return 0;
+  }
+  return option_nr;
+}
+
 int main (int argc, char **argv)
 {
   halevt_mount_udi *current_udi;
@@ -705,6 +722,8 @@ int main (int argc, char **argv)
   int num_devices;
   int system_user = 0;
   char *mask_string;
+  char uid_nr[50];
+  char *uid_string;
 
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, DATADIR "/locale/");
@@ -773,27 +792,12 @@ int main (int argc, char **argv)
            exit (1);
          }
        case 'o':
-         option_nr++;
-         if ((realloc (options_array, option_nr * sizeof(char *))) == NULL)
-         {
-           fprintf (stderr, _("Out of memory\n"));
-           exit (1);
-         }
-         if ((options_array[option_nr - 1] = strdup(optarg)) == NULL)
-         {
-           fprintf (stderr, _("Out of memory\n"));
-           exit (1);
-         }
+         option_nr = halevt_mount_add_option(options_array, optarg, option_nr);
+         if (option_nr == 0) { exit (1); }
          break;
        case 'm':
          if (system_user)
          {
-           option_nr++;
-           if ((realloc (options_array, option_nr * sizeof(char *))) == NULL)
-           {
-             fprintf (stderr, _("Out of memory\n"));
-             exit (1);
-           }
            if ((mask_string = (char *) malloc ((1 + strlen (optarg) + strlen (MASKOPTSTR)) * sizeof(char))) == NULL)
            {
              fprintf (stderr, _("Out of memory\n"));
@@ -801,12 +805,8 @@ int main (int argc, char **argv)
            }
            strcpy (mask_string, MASKOPTSTR);
            strcat (mask_string, optarg);
-           options_array[option_nr - 1] = mask_string;
-           if ((options_array[option_nr - 1] = strdup(mask_string)) == NULL)
-           {
-             fprintf (stderr, _("Out of memory\n"));
-             exit (1);
-           }
+           option_nr = halevt_mount_add_option(options_array, mask_string, option_nr);
+           if (option_nr == 0) { exit (1); }
            free (mask_string);
          }
          break;
@@ -1059,6 +1059,22 @@ int main (int argc, char **argv)
 
     if (mountpoint == NULL) { mountpoint = ""; }
 
+    if (! system_user)
+    {
+       snprintf(uid_nr, 49, "%d", getuid());
+       uid_nr[49] = '\0';
+       if ((uid_string = (char *) malloc ((1 + strlen (uid_nr) + strlen (UIDOPTSTR)) * sizeof(char))) == NULL)
+       {
+          fprintf (stderr, _("Out of memory\n"));
+          exit (1);
+       }
+       strcpy (uid_string, UIDOPTSTR);
+       strcat (uid_string, uid_nr);
+       
+       option_nr = halevt_mount_add_option(options_array, uid_string, option_nr);
+       if (option_nr == 0) { exit (1); }
+       free (uid_string);
+    }
     if (! (dbus_message_append_args (dbus_msg,
        DBUS_TYPE_STRING, &mountpoint, DBUS_TYPE_STRING, &fstype,
        DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options_array, option_nr,
